package com.bweb.controller;

import com.alibaba.excel.EasyExcel;
import com.bweb.config.SysConst;
import com.bweb.model.ExportHighOrderModel;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.model.HighOrderModel;
import com.hai.model.HighUserModel;
import com.hai.model.ResponseData;
import com.hai.model.UserInfoModel;
import com.hai.service.HighCouponCodeService;
import com.hai.service.HighCouponService;
import com.hai.service.HighOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Auther: 袁野
 * @Description:
 * @Date: 2021/3/26 23:08
 */
@Controller
@RequestMapping(value = "/highOrder")
@Api(value = "订单接口")
public class HighOrderController {

    private static Logger log = LoggerFactory.getLogger(HighMerchantStoreController.class);

    @Autowired
    private UserCenter userCenter;

    @Resource
    private HighOrderService highOrderService;

    @Resource
    private HighCouponCodeService highCouponCodeService;


    @RequestMapping(value = "/getOrderById", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "根据id查询订单详情")
    public ResponseData getOrderById(@RequestParam(name = "orderId", required = true) Long orderId) {
        try {

            return ResponseMsgUtil.success(highOrderService.getOrderById(orderId));

        } catch (Exception e) {
            log.error("HighOrderController --> getOrderById() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/getOrderCouponList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取卡券订单列表")
    public ResponseData getUserOrderList(@RequestParam(name = "pageNum", required = true) Integer pageNum,
                                         @RequestParam(name = "pageSize", required = true) Integer pageSize,
                                         @RequestParam(name = "status", required = false) Integer status,
                                         @RequestParam(name = "couponId", required = false) Integer couponId,
                                         @RequestParam(name = "salesCode", required = false) Integer salesCode,
                                         HttpServletRequest request) {
        try {

            Map<String,Object> map = new HashMap<>();

            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();
            if (userInfoModel.getBsCompany() == null) {
                log.error("HighCouponController -> getCouponList() error!","权限不足");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
            }
//            map.put("companyId", userInfoModel.getBsCompany().getId());
            map.put("couponId", couponId);
            map.put("salesCode", salesCode);
            map.put("status", status);

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highCouponCodeService.getCouponCodeList(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getUserOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getOrderBList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取用户订单")
    public ResponseData getOrderBList(
            @RequestParam(name = "orderStatus", required = false) Integer orderStatus,
            @RequestParam(name = "orderNo", required = false) String orderNo,
            @RequestParam(name = "memPhone", required = false) String memPhone,
            @RequestParam(name = "pageNum", required = true) Integer pageNum,
            @RequestParam(name = "pageSize", required = true) Integer pageSize,
            HttpServletRequest request) {
        try {

            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();


            Map<String,Object> map = new HashMap<>();

            if (userInfoModel.getSecRole().getRoleType() == 5) {
              map.put("companyId" , userInfoModel.getBsCompany().getId());
            }
            if (userInfoModel.getSecRole().getRoleType() == 2) {
                map.put("merchantId" , userInfoModel.getMerchant().getId());
            }
            if (userInfoModel.getSecRole().getRoleType() == 3) {
                map.put("storeId" , userInfoModel.getMerchantStore().getId());
            }
            map.put("orderStatus", orderStatus);
            map.put("orderNo", orderNo);
            map.put("memPhone", memPhone);

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highOrderService.getOrderBList(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getUserOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/getGoodsOrderList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询商品订单列表")
    public ResponseData getGoodsOrderList(@RequestParam(name = "companyId", required = false) Long companyId,
                                          @RequestParam(name = "merchantId", required = false) Long merchantId,
                                          @RequestParam(name = "orderNo", required = false) String orderNo,
                                          @RequestParam(name = "paySerialNo", required = false) String paySerialNo,
                                          @RequestParam(name = "payModel", required = false) Integer payModel,
                                          @RequestParam(name = "payType", required = false) Integer payType,
                                          @RequestParam(name = "orderStatus", required = false) Integer orderStatus,
                                          @RequestParam(name = "createTimeS", required = false) Long createTimeS,
                                          @RequestParam(name = "createTimeE", required = false) Long createTimeE,
                                          @RequestParam(name = "payTimeS", required = false) Long payTimeS,
                                          @RequestParam(name = "payTimeE", required = false) Long payTimeE,
                                          @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                          @RequestParam(name = "pageSize", required = true) Integer pageSize,
                                          HttpServletRequest request) {
        try {

            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();

            Map<String,Object> map = new HashMap<>();
            // 用户来源 0：超级管理员  1：公司  2：商户  3：门店 4. 代理商
            if(userInfoModel.getSecUser().getObjectType() == 0) {
                map.put("companyId", companyId);

            } else if (userInfoModel.getSecUser().getObjectType() == 1) {
                map.put("companyId", userInfoModel.getBsCompany().getId());
                map.put("merchantId", merchantId);

            } else if (userInfoModel.getSecUser().getObjectType() == 2) {
                map.put("merchantId", userInfoModel.getMerchant().getId());
            }

            map.put("orderNo", orderNo);
            map.put("paySerialNo", paySerialNo);
            map.put("payModel", payModel);
            map.put("payType", payType);
            map.put("orderStatus", orderStatus);
            map.put("createTimeS", createTimeS);
            map.put("createTimeE", createTimeE);
            map.put("payTimeS", payTimeS);
            map.put("payTimeE", payTimeE);

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highOrderService.getGoodsOrderModelList(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getUserOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/exportGoodsOrderList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "导出商品订单列表")
    public ResponseData exportGoodsOrderList(@RequestParam(name = "companyId", required = false) Long companyId,
                                             @RequestParam(name = "merchantId", required = false) Long merchantId,
                                             @RequestParam(name = "orderNo", required = false) String orderNo,
                                             @RequestParam(name = "paySerialNo", required = false) String paySerialNo,
                                             @RequestParam(name = "payModel", required = false) Integer payModel,
                                             @RequestParam(name = "payType", required = false) Integer payType,
                                             @RequestParam(name = "orderStatus", required = false) Integer orderStatus,
                                             @RequestParam(name = "createTimeS", required = false) Long createTimeS,
                                             @RequestParam(name = "createTimeE", required = false) Long createTimeE,
                                             @RequestParam(name = "payTimeS", required = false) Long payTimeS,
                                             @RequestParam(name = "payTimeE", required = false) Long payTimeE,
                                             HttpServletRequest request) {
        try {
            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();
            Map<String,Object> map = new HashMap<>();
            // 用户来源 0：超级管理员  1：公司  2：商户  3：门店 4. 代理商
            if(userInfoModel.getSecUser().getObjectType() == 0) {
                map.put("companyId", companyId);
                map.put("merchantId", merchantId);

            } else if (userInfoModel.getSecUser().getObjectType() == 1) {
                map.put("companyId", userInfoModel.getBsCompany().getId());
                map.put("merchantId", merchantId);

            } else if (userInfoModel.getSecUser().getObjectType() == 2) {
                map.put("merchantId", userInfoModel.getMerchant().getId());
            }

            map.put("orderNo", orderNo);
            map.put("paySerialNo", paySerialNo);
            map.put("payModel", payModel);
            map.put("payType", payType);
            map.put("orderStatus", orderStatus);
            map.put("createTimeS", createTimeS);
            map.put("createTimeE", createTimeE);
            map.put("payTimeS", payTimeS);
            map.put("payTimeE", payTimeE);

            String name = "/goodsOrder/商品订单" + System.currentTimeMillis() + ".xlsx";
            List<HighOrderModel> list = highOrderService.getGoodsOrderModelList(map);
            String fileName = SysConst.getSysConfig().getFileUrl() + name;
            EasyExcel.write(fileName, ExportHighOrderModel.class).sheet("商品订单").doWrite(list);
            return ResponseMsgUtil.success(name);

        } catch (Exception e) {
            log.error("HighOrderController --> exportGoodsOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/getGasOrderList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询加油订单列表")
    public ResponseData getGasOrderList(@RequestParam(name = "companyId", required = false) Long companyId,
                                          @RequestParam(name = "merchantId", required = false) Long merchantId,
                                          @RequestParam(name = "orderNo", required = false) String orderNo,
                                          @RequestParam(name = "paySerialNo", required = false) String paySerialNo,
                                          @RequestParam(name = "payModel", required = false) Integer payModel,
                                          @RequestParam(name = "payType", required = false) Integer payType,
                                          @RequestParam(name = "orderStatus", required = false) Integer orderStatus,
                                          @RequestParam(name = "createTimeS", required = false) Long createTimeS,
                                          @RequestParam(name = "createTimeE", required = false) Long createTimeE,
                                          @RequestParam(name = "payTimeS", required = false) Long payTimeS,
                                          @RequestParam(name = "payTimeE", required = false) Long payTimeE,
                                          @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                          @RequestParam(name = "pageSize", required = true) Integer pageSize,
                                          HttpServletRequest request) {
        try {

            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();

            Map<String,Object> map = new HashMap<>();
            // 用户来源 0：超级管理员  1：公司  2：商户  3：门店 4. 代理商
            if(userInfoModel.getSecUser().getObjectType() == 0) {
                map.put("companyId", companyId);

            } else if (userInfoModel.getSecUser().getObjectType() == 1) {
                map.put("companyId", userInfoModel.getBsCompany().getId());
                map.put("merchantId", merchantId);

            } else if (userInfoModel.getSecUser().getObjectType() == 2) {
                map.put("merchantId", userInfoModel.getMerchant().getId());
            }

            map.put("orderNo", orderNo);
            map.put("paySerialNo", paySerialNo);
            map.put("payModel", payModel);
            map.put("payType", payType);
            map.put("orderStatus", orderStatus);
            map.put("createTimeS", createTimeS);
            map.put("createTimeE", createTimeE);
            map.put("payTimeS", payTimeS);
            map.put("payTimeE", payTimeE);

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highOrderService.getGasOrderModelList(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getGasOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getKfcOrderList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询KFC订单列表")
    public ResponseData getKfcOrderList(@RequestParam(name = "companyId", required = false) Long companyId,
                                        @RequestParam(name = "merchantId", required = false) Long merchantId,
                                        @RequestParam(name = "orderNo", required = false) String orderNo,
                                        @RequestParam(name = "paySerialNo", required = false) String paySerialNo,
                                        @RequestParam(name = "payModel", required = false) Integer payModel,
                                        @RequestParam(name = "payType", required = false) Integer payType,
                                        @RequestParam(name = "orderStatus", required = false) Integer orderStatus,
                                        @RequestParam(name = "createTimeS", required = false) Long createTimeS,
                                        @RequestParam(name = "createTimeE", required = false) Long createTimeE,
                                        @RequestParam(name = "payTimeS", required = false) Long payTimeS,
                                        @RequestParam(name = "payTimeE", required = false) Long payTimeE,
                                        @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                        @RequestParam(name = "pageSize", required = true) Integer pageSize,
                                        HttpServletRequest request) {
        try {

            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();

            Map<String,Object> map = new HashMap<>();
            // 用户来源 0：超级管理员  1：公司  2：商户  3：门店 4. 代理商
            if(userInfoModel.getSecUser().getObjectType() == 0) {
                map.put("companyId", companyId);

            } else if (userInfoModel.getSecUser().getObjectType() == 1) {
                map.put("companyId", userInfoModel.getBsCompany().getId());
                map.put("merchantId", merchantId);

            } else if (userInfoModel.getSecUser().getObjectType() == 2) {
                map.put("merchantId", userInfoModel.getMerchant().getId());
            }

            map.put("orderNo", orderNo);
            map.put("paySerialNo", paySerialNo);
            map.put("payModel", payModel);
            map.put("payType", payType);
            map.put("orderStatus", orderStatus);
            map.put("createTimeS", createTimeS);
            map.put("createTimeE", createTimeE);
            map.put("payTimeS", payTimeS);
            map.put("payTimeE", payTimeE);

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highOrderService.getKfcOrderModelList(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getGasOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getCinemaOrderList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询电影订单列表")
    public ResponseData getCinemaOrderList(@RequestParam(name = "companyId", required = false) Long companyId,
                                        @RequestParam(name = "merchantId", required = false) Long merchantId,
                                        @RequestParam(name = "orderNo", required = false) String orderNo,
                                        @RequestParam(name = "paySerialNo", required = false) String paySerialNo,
                                        @RequestParam(name = "payModel", required = false) Integer payModel,
                                        @RequestParam(name = "payType", required = false) Integer payType,
                                        @RequestParam(name = "orderStatus", required = false) Integer orderStatus,
                                        @RequestParam(name = "createTimeS", required = false) Long createTimeS,
                                        @RequestParam(name = "createTimeE", required = false) Long createTimeE,
                                        @RequestParam(name = "payTimeS", required = false) Long payTimeS,
                                        @RequestParam(name = "payTimeE", required = false) Long payTimeE,
                                        @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                        @RequestParam(name = "pageSize", required = true) Integer pageSize,
                                        HttpServletRequest request) {
        try {

            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();

            Map<String,Object> map = new HashMap<>();
            // 用户来源 0：超级管理员  1：公司  2：商户  3：门店 4. 代理商
            if(userInfoModel.getSecUser().getObjectType() == 0) {
                map.put("companyId", companyId);

            } else if (userInfoModel.getSecUser().getObjectType() == 1) {
                map.put("companyId", userInfoModel.getBsCompany().getId());
                map.put("merchantId", merchantId);

            } else if (userInfoModel.getSecUser().getObjectType() == 2) {
                map.put("merchantId", userInfoModel.getMerchant().getId());
            }

            map.put("orderNo", orderNo);
            map.put("paySerialNo", paySerialNo);
            map.put("payModel", payModel);
            map.put("payType", payType);
            map.put("orderStatus", orderStatus);
            map.put("createTimeS", createTimeS);
            map.put("createTimeE", createTimeE);
            map.put("payTimeS", payTimeS);
            map.put("payTimeE", payTimeE);

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highOrderService.getCinemaOrderList(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getGasOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getMobileOrderList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询话费充值订单列表")
    public ResponseData getMobileOrderList(@RequestParam(name = "companyId", required = false) Long companyId,
                                           @RequestParam(name = "merchantId", required = false) Long merchantId,
                                           @RequestParam(name = "orderNo", required = false) String orderNo,
                                           @RequestParam(name = "paySerialNo", required = false) String paySerialNo,
                                           @RequestParam(name = "payModel", required = false) Integer payModel,
                                           @RequestParam(name = "payType", required = false) Integer payType,
                                           @RequestParam(name = "orderStatus", required = false) Integer orderStatus,
                                           @RequestParam(name = "createTimeS", required = false) Long createTimeS,
                                           @RequestParam(name = "createTimeE", required = false) Long createTimeE,
                                           @RequestParam(name = "payTimeS", required = false) Long payTimeS,
                                           @RequestParam(name = "payTimeE", required = false) Long payTimeE,
                                           @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                           @RequestParam(name = "pageSize", required = true) Integer pageSize,
                                           HttpServletRequest request) {
        try {

            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();

            Map<String,Object> map = new HashMap<>();
            // 用户来源 0：超级管理员  1：公司  2：商户  3：门店 4. 代理商
            if(userInfoModel.getSecUser().getObjectType() == 0) {
                map.put("companyId", companyId);

            } else if (userInfoModel.getSecUser().getObjectType() == 1) {
                map.put("companyId", userInfoModel.getBsCompany().getId());
                map.put("merchantId", merchantId);

            } else if (userInfoModel.getSecUser().getObjectType() == 2) {
                map.put("merchantId", userInfoModel.getMerchant().getId());
            }

            map.put("orderNo", orderNo);
            map.put("paySerialNo", paySerialNo);
            map.put("payModel", payModel);
            map.put("payType", payType);
            map.put("orderStatus", orderStatus);
            map.put("createTimeS", createTimeS);
            map.put("createTimeE", createTimeE);
            map.put("payTimeS", payTimeS);
            map.put("payTimeE", payTimeE);

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highOrderService.getMobileOrderList(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getGasOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


}

